# edureporter

Пакет инструментов для построения отчетных систем.

## Установка

```bash

  $ pip install edureporter

```

## Тестирование

Для запуска тестов используется tox.

Установка tox:

```bash

$ pip install tox

```

Запуск тестов из директории пакета:

```bash

$ tox

```
